@@ -21,6 +21,7 @@ class User(BaseModel):
 
     name = sa.Column(sa.Unicode(32), nullable=False)
     email = sa.Column(sa.Unicode(256), nullable=False, default='')
+    count = sa.Column(sa.Integer, nullable=False, default=0)
 
     @classmethod
     def initial_data(cls, dbs):
@@ -29,8 +30,9 @@ class User(BaseModel):
             if not users:
                 for j in range(2):
                     cls.create(dbs, {
-                        cls.name: 'foobar_%s_%s' % (i, j),
-                        cls.email: 'foobar_%s@domain_%s' % (i, j),
+                        'name': 'foobar_%s_%s' % (i, j),
+                        'email': 'foobar_%s@domain_%s' % (i, j),
+                        'count': 0,
                     })
 
 if __name__ == '__main__':
@@ -68,24 +70,26 @@ if __name__ == '__main__':
         # checking DB
         print("*" * 50)
         print("All entries:")
-        with dbh as dbs:
+        with dbh.session_context() as dbs:
             for usr in User.find(dbs, None):
                 print(usr)
         print("*" * 50)
+
         print("Filter & modify entries:")
-        with dbh as dbs:
+        with dbh.session_context() as dbs:
             users = User.find(dbs, (User.or_(
                 User.name.like('foobar_2_%%'),
                 User.name.like('foobar_4_%%')),))
-        with dbh as dbs:
+        with dbh.session_context() as dbs:
             for usr in users:
                 print(usr)
                 usr.modify(dbs, {
-                    User.name: usr.name + '_#',
+                    'name': usr.name + '_#',
                 })
+
         print("*" * 50)
         print("All entries after modify:")
-        with dbh as dbs:
+        with dbh.session_context() as dbs:
             for usr in User.find(dbs, None):
                 print(usr)
         print("*" * 50)
